/* -*- C++ -*-
 * lemon/lp.h - Part of LEMON, a generic C++ optimization library
 *
 * Copyright (C) 2005 Egervary Jeno Kombinatorikus Optimalizalasi Kutatocsoport
 * (Egervary Research Group on Combinatorial Optimization, EGRES).
 *
 * Permission to use, modify and distribute this software is granted
 * provided that this copyright notice appears in all copies. For
 * precise terms see the accompanying LICENSE file.
 *
 * This software is provided "AS IS" with no warranty of any kind,
 * express or implied, and with no claim as to its suitability for any
 * purpose.
 *
 */

#ifndef LEMON_LP_H
#define LEMON_LP_H

#ifdef HAVE_CONFIG_H
#include<lemon/config.h>
#endif

#ifdef HAVE_GLPK
#include <lemon/lp_glpk.h>
#elif HAVE_CPLEX
#include <lemon/lp_cplex.h>
#endif

///\file
///\brief Defines a default LP solver
///\ingroup gen_opt_group
namespace lemon {
 
#ifdef DOXYGEN
  ///The default LP solver identifier

  ///The default LP solver identifier.
  ///\ingroup gen_opt_group
  ///
  ///Currently, the possible values are \c GLPK or \c CPLEX
#define DEFAULT_LP SOLVER
  ///The default LP solver

  ///The default LP solver.
  ///\ingroup gen_opt_group
  ///
  ///Currently, it is either \c LpGlpk or \c LpCplex
  typedef LpGlpk Lp;
  ///The default LP solver identifier string

  ///The default LP solver identifier string.
  ///\ingroup gen_opt_group
  ///
  ///Currently, the possible values are "GLPK" or "CPLEX"
  const char default_solver_name[]="SOLVER";  
#else
#ifdef HAVE_GLPK
#define DEFAULT_LP GLPK
  typedef LpGlpk Lp;
  const char default_solver_name[]="GLPK";
#elif HAVE_CPLEX
#define DEFAULT_LP CPLEX
  typedef LpCplex Lp;
  const char default_solver_name[]="CPLEX";
#endif
#endif
 
} //namespace lemon

#endif //LEMON_LP_BASE_H
